@@ -3,7 +3,6 @@ from django.apps import AppConfig
 from django.conf import settings
 import sys
 
-
 class MicroserviceAdminConfig(AppConfig):
     default_auto_field = 'django.db.models.BigAutoField'
     name = 'django_microservice_admin'
@@ -16,8 +15,10 @@ class MicroserviceAdminConfig(AppConfig):
 
         from .models import AdminApps
 
-        MICROSERVICE_ADMIN_APP_VARS = ['MICROSERVICE_ADMIN_APP_HOST', 'MICROSERVICE_ADMIN_APP_ORDER']
+        MICROSERVICE_ADMIN_APP_VARS = ['MICROSERVICE_ADMIN_PROJECT_NAME','MICROSERVICE_ADMIN_APP_HOST','MICROSERVICE_ADMIN_APP_SECRET_KEY_HEADER','MICROSERVICE_ADMIN_TITLE','MICROSERVICE_REDIRECT_PATH',]
 
         for var in MICROSERVICE_ADMIN_APP_VARS:
             if not hasattr(settings, var):
-                raise Exception(f"Missing {var} in settings.py")
\ No newline at end of file
+                raise Exception(f"Missing {var} in settings.py")
+        
+        AdminApps.objects.filter(project_name=settings.MICROSERVICE_ADMIN_PROJECT_NAME).delete()
